## Modules
### server
- imm-common: pre-requisted, which includes basemodels, utils, etc...
#### API
- api: For all API modules 
#### modules
- bcpnp: BCPNP applications
- lmia: LMIA applications
- pr: PR applications
- tr: TR applications
#### system
- data: all excel, pdf,word templates, etc...  used by the system
- doc: docs, but did not do it so far
- system: config and models index
### client
- client: apps used in terminal with http accessing to api
- local: apps used in terminal with local accessing to modules
### test
- tests: test apps